import React, { useEffect, useState } from 'react'
import { withClient, Client } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import Card from 'components/ContentComponents/Card/Card'
import FluidService, { ProcessedData } from 'services/fluidService'
import { FluidType } from 'enum/fluid.enum'
import Spinner from 'cozy-ui/react/Spinner'

interface CardsContainerProps {
  client: Client
  t: Function
}

const CardsContainer = ({ client, t }) => {
  const [isLoading, setIsLoading] = useState(true)
  const [elecCardProps, setElecCardProps] = useState<ProcessedData | null>(null)
  const [gasCardProps, setGasCardProps] = useState<ProcessedData | null>(null)
  const [waterCardProps, setWaterCardProps] = useState<ProcessedData | null>(
    null
  )

  useEffect(() => {
    const fluidService = new FluidService(client)
    // flag use to prevent error linked to re-rendering
    let subscribed = true
    async function getData() {
      const [elecData, gasData, waterData] = await Promise.all([
        fluidService.getLastTwoWeeks(FluidType.ELECTRICITY),
        fluidService.getLastTwoWeeks(FluidType.GAS),
        fluidService.getLastTwoWeeks(FluidType.WATER),
      ])
      if (subscribed) {
        setElecCardProps(fluidService.processElectricityData(elecData.data))
        setGasCardProps(fluidService.processGasData(gasData.data))
        setWaterCardProps(fluidService.processWaterData(waterData.data))
        setIsLoading(false)
      }
    }
    getData()

    return () => {
      subscribed = false
    }
  }, [])
  return (
    <React.Fragment>
      {isLoading ? (
        <Spinner size="xxlarge" middle />
      ) : (
        <div>
          <p className="home-title">{t('COMMON.CONSO_DETAILS')}</p>
          {elecCardProps && (
            <Card type={FluidType.ELECTRICITY} {...elecCardProps} />
          )}
          {waterCardProps && (
            <Card type={FluidType.WATER} {...waterCardProps} />
          )}
          {gasCardProps && <Card type={FluidType.GAS} {...gasCardProps} />}
        </div>
      )}
    </React.Fragment>
  )
}

export default translate()(withClient(CardsContainer))
